<?php
namespace SM\Factory;

use Doctrine\ORM\EntityManager;
use SM\Traits\TQuery;

class ClientesNaoFaturadosRelatorioFactory {

    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getClientesNaoFaturadosRelatorio() {
        $sql ="SELECT * FROM (
            SELECT CONT.NRCONTRATOFCT,
                        PARC.NRPARCNEGOCIO,
                        ORCA.NRSEQORCAMENTO,
                        ORCA.NRORCAMENTO,
                        MED.NRSEQCONTRATO,
                        PARC.NMPRINCIPALPARC,
                        DECODE(PARC.IDATIVO , 'S', 'Sim', 'Não') AS IDATIVOPARC,
                        TIPO.NMTIPOORCAMENTO,
                        TIPO.NRTIPOORCAMENTO,
                        MED.IDSITUACAO AS TPFATURAMENTO,
                        MED.IDTPFATURA,
                        MED.DTINICOMPET,
                        CASE WHEN MED.IDTPFATURA = 'A' THEN
                            'Periódico (valor de parcela fixo)'
                        WHEN MED.IDTPFATURA = 'P' THEN
                            'Parcelamento (Quantidade de Parcelas)'
                        WHEN MED.IDTPFATURA = 'X' THEN
                            'Periódico (Valor Apurado por Medição)'
                        ELSE
                            ''
                        END AS NMTPFATURA,
                        TO_CHAR(MED.DTINICOMPET,'DD/MM/YYYY') || ' - '|| TO_CHAR(MED.DTFINCOMPET,'DD/MM/YYYY') AS DTCOMPET,
                        CASE WHEN MED.IDSITUACAO = '1' AND MED.DTLIMITEAPU < SYSDATE THEN
                            'Parcela passou da data limite de apuração e está pendente de apuração.'
                        WHEN MED.IDSITUACAO in ('2') THEN
                            TO_CHAR('Nota fiscal pendente de transmissão (Nota Fiscal: '|| NOTA.NRLANCTONF || ')')
                        WHEN MED.IDSITUACAO = '4' THEN
                            TO_CHAR('Parcela cancelada (Justificativa: '|| MED.DSJUSTIFICATIVA ||')')
                        ELSE
                            '' --cai no else quando não entra em nenhum dos WHEN descritos acima
                        END AS MOTIVO,
                        CASE WHEN MED.IDSITUACAO = '1' AND MED.DTLIMITEAPU < SYSDATE THEN
                            '1'--'Parcela passou da data limite de apuração e está pendente de apuração.'
                        WHEN MED.IDSITUACAO in ('2') THEN
                            '2'--TO_CHAR('Nota fiscal pendente de transmissão (Nota Fiscal: '|| NOTA.NRLANCTONF || ')')
                        WHEN MED.IDSITUACAO = '4' THEN
                            '3'--TO_CHAR('Parcela cancelada (Justificativa: '|| MED.DSJUSTIFICATIVA ||')')
                        ELSE
                            '' --cai no else quando não entra em nenhum dos WHEN descritos acima
                        END AS IDMOTIVO
                FROM FCT_FATURACONT MED
                INNER JOIN FCT_RELACAGRUPCONTFAT RELA ON RELA.NRFATURACONT = MED.NRFATURACONT
                INNER JOIN FCT_CONTRATO CONT ON CONT.NRSEQCONTRATO = RELA.NRSEQCONTRATO
                INNER JOIN FCT_FATURACONT FATU  ON FATU.NRFATURACONT = RELA.NRFATURACONT
                INNER JOIN PARCNEGOCIO PARC ON PARC.NRPARCNEGOCIO = CONT.NRPARCNEGOCIO
                INNER JOIN FCT_ORCAMENTO ORCA ON ORCA.NRPARCNEGOCIO = PARC.NRPARCNEGOCIO
                INNER JOIN FCT_TIPOORCAMENTO TIPO ON TIPO.NRTIPOORCAMENTO = ORCA.NRTIPOORCAMENTO
                LEFT JOIN FCT_RELACAPURACAOFATURA RELAFAT ON RELAFAT.NRFATURACONT = MED.NRFATURACONT
                LEFT JOIN FCT_APURACAO APU ON APU.NRAPURACAO = RELAFAT.NRAPURACAO
                LEFT JOIN NOTAFISCAL NOTA ON NOTA.NRLANCTONF = APU.NRLANCTONF AND NOTA.CDFILIAL = APU.CDFILIAL
                WHERE MED.IDSITUACAO IN ('1','2','4')
                UNION   
                SELECT CONT.NRCONTRATOFCT,
                        PARC.NRPARCNEGOCIO,
                        ORCA.NRSEQORCAMENTO,
                        ORCA.NRORCAMENTO,
                        MED.NRSEQCONTRATO,
                        PARC.NMPRINCIPALPARC,
                        DECODE(PARC.IDATIVO , 'S', 'Sim', 'Não') AS IDATIVOPARC,
                        TIPO.NMTIPOORCAMENTO,
                        TIPO.NRTIPOORCAMENTO,
                        MED.IDSITUACAO AS TPFATURAMENTO,
                        'X' AS IDTPFATURA,
                        MED.DTINICOMPET,
                        'Periódico (Valor Apurado por Medição)' AS NMTPFATURA,
                            TO_CHAR(MED.DTINICOMPET,'DD/MM/YYYY') || ' - '|| TO_CHAR(MED.DTFINCOMPET,'DD/MM/YYYY') AS DTCOMPET,
                        CASE WHEN MED.IDSITUACAO = '6' THEN
                            TO_CHAR('Medição de faturamento cancelada (justificativa: ' || MED.DSJUSTIFICACANC || ')')
                        WHEN MED.IDSITUACAO IN ('1', '3') AND SYSDATE > MED.DTFINCOMPET THEN
                            'Medição passou da data final de competência e ainda não foi gerada'
                        ELSE
                            '' --cai no else quando não entra em nenhum dos WHEN descritos acima
                        END AS MOTIVO,
                        CASE WHEN MED.IDSITUACAO = '6' THEN
                            '4'--TO_CHAR('Medição de faturamento cancelada (justificativa: ' || MED.DSJUSTIFICACANC || ')')
                        WHEN MED.IDSITUACAO IN ('1', '3') AND SYSDATE > MED.DTFINCOMPET THEN
                            '5'--'Medição passou da data final de competência e ainda não foi gerada'
                        ELSE
                            '' --cai no else quando não entra em nenhum dos WHEN descritos acima
                        END AS IDMOTIVO
                FROM FCT_MEDICAOFATURA MED
                INNER JOIN FCT_CONTRATO CONT ON CONT.NRSEQCONTRATO = MED.NRSEQCONTRATO
                INNER JOIN PARCNEGOCIO PARC ON PARC.NRPARCNEGOCIO = CONT.NRPARCNEGOCIO
                INNER JOIN FCT_ORCAMENTO ORCA ON ORCA.NRPARCNEGOCIO = PARC.NRPARCNEGOCIO
                INNER JOIN FCT_TIPOORCAMENTO TIPO ON TIPO.NRTIPOORCAMENTO = ORCA.NRTIPOORCAMENTO
                WHERE MED.IDSITUACAO IN ('1','3','6')
            )WHERE MOTIVO IS NOT NULL";
    
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }
}