<?php
namespace SM\Factory;

use Doctrine\ORM\EntityManager;
use SM\Traits\TQuery;

class Sm00050001QuantidadeMaximaParcelasOperadorFactory {

    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getQuantidadeMaximaParcelasOperador() {

        $sql = "SELECT QT.NRQTPARCMAXIMAOPER, QT.QTPARCMAXIMAOPER, QT.CDOPERADOR,OP.NMOPERADOR
                    FROM FCT_QTPARCMAXIMAOPER QT
                    INNER JOIN OPERADOR OP 
                    ON QT.CDOPERADOR = OP.CDOPERADOR";
        
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function validaQtdMaximaParcelasOperador(array $params){

        $sql = "SELECT COUNT (*) AS QTD
                FROM FCT_QTPARCMAXIMAOPER
                WHERE CDOPERADOR = :CDOPERADOR
                AND NRQTPARCMAXIMAOPER <> NVL(:NRQTPARCMAXIMAOPER,-1)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();

    }

    public function insertQtdMaximaParcelasOperador (array $params){
        
        $sql = "INSERT INTO FCT_QTPARCMAXIMAOPER (
            NRQTPARCMAXIMAOPER,   CDOPERADOR,   QTPARCMAXIMAOPER,
            NRORG,                IDATIVO,      DTINCLUSAO,   
            NRORGINCLUSAO,        CDOPERINCLUSAO
        )
        VALUES (
            :NRQTPARCMAXIMAOPER,   :CDOPERADOR,   :QTPARCMAXIMAOPER,
            :NRORG,                :IDATIVO,       SYSDATE,    
            :NRORGINCLUSAO,        :CDOPERINCLUSAO
        )";

        $this->connection->executeStatement($sql, $params);
    }
    
    public function updateQtdMaximaParcelasOperador($params){
        $sql = "UPDATE FCT_QTPARCMAXIMAOPER 
        SET CDOPERADOR = :CDOPERADOR, 
        QTPARCMAXIMAOPER = :QTPARCMAXIMAOPER,
        NRORG = :NRORG, 
        IDATIVO = :IDATIVO,
        NRORGINCLUSAO = :NRORGINCLUSAO,
        CDOPERINCLUSAO = : CDOPERINCLUSAO
        WHERE NRQTPARCMAXIMAOPER = :NRQTPARCMAXIMAOPER";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deleteQtdMaximaParcelasOperador($params){
        $sql = "DELETE FROM FCT_QTPARCMAXIMAOPER WHERE NRQTPARCMAXIMAOPER = :NRQTPARCMAXIMAOPER";
        $this->connection->executeStatement($sql, $params);
    }
    
}