<?php

namespace SM\Factory;

use Doctrine\ORM\EntityManager;
use SM\Traits\TQuery;

class Sm00057001ConfiguracaoRegionalIdiomaFactory
{

    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getConfiguracaoRegionalIdioma()
    {
        $sql = "SELECT CDIDIOM,
                       NMIDIOMA,
                       DTULTATUIDIOMA,
                       NRORG,
                       DTINCLUSAO,
                       DTULTATU,
                       NRORGINCLUSAO,
                       CDOPERINCLUSAO,
                       NRORGULTATU,
                       CDOPERULTATU,
                       IDATIVO,
                       IDPADRAO
                    FROM IDIOMA";
        
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function validaConfiguracaoRegionalIdioma($parametros)
    {
        $sql = "SELECT COUNT(*) AS VALIDAIDIOMA
                  FROM IDIOMA
                 WHERE NMIDIOMA = :NMIDIOMA
                   AND CDIDIOM  <> NVL(:CDIDIOM ,-1)";
        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
        return $std->fetchAll();    
    }

    public function inserirConfiguracaoRegionalIdioma($parametros)
    {
        $sql = "INSERT INTO  IDIOMA (
                    CDIDIOM, NMIDIOMA, NRORG, DTINCLUSAO,
                    NRORGINCLUSAO,CDOPERINCLUSAO,
                    IDATIVO,IDPADRAO
                )
                VALUES (
                    :CDIDIOM, :NMIDIOMA, :NRORG,SYSDATE,    
                    :NRORGINCLUSAO,:CDOPERINCLUSAO, 
                    :IDATIVO, :IDPADRAO
                )";
        
        $this->connection->executeStatement($sql, $parametros);
    }

    public function atualizarConfiguracaoRegionalIdioma($parametros)
    {
        $sql = "UPDATE IDIOMA
                   SET NMIDIOMA = :NMIDIOMA,
                       DTULTATUIDIOMA = SYSDATE,
                       NRORG = :NRORG,
                       DTULTATU = SYSDATE,
                       NRORGULTATU = :NRORGULTATU,
                       CDOPERULTATU = :CDOPERULTATU,
                       IDATIVO = :IDATIVO,
                       IDPADRAO = :IDPADRAO
                 WHERE CDIDIOM  = :CDIDIOM";
        
        $this->connection->executeStatement($sql, $parametros);
    }

    public function atualizarConfiguracaoRegionalIdPadraoIdioma($parametros)
    {
        $sql = "UPDATE IDIOMA
                   SET IDPADRAO = :IDPADRAO
                 WHERE CDIDIOM  <> :CDIDIOM";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function deletarConfiguracaoRegionalIdioma($parametros)
    {
        $sql = "DELETE FROM IDIOMA WHERE CDIDIOM = :CDIDIOM ";
        $this->connection->executeStatement($sql, $parametros);
    }
}
